@@ -387,7 +387,7 @@ class Schwefel(BenchmarkFunction):
 	def __init__(self, n_dimensions=2, opposite=False):
 		super().__init__("Schwefel", n_dimensions, opposite)
 	def _evaluate(self,point):
-		ret = sum([-p*math.sin(math.sqrt(abs(p))) for p in point])
+		ret = 418.9829*self.n_dimensions() - sum([p*math.sin(math.sqrt(abs(p))) for p in point])
 		return ret
 	# def _evaluate_derivative(self, point):
 	# 	if point==[0.0]*len(point):
